class Settings:
    def __init__(self, client):
        self.client = client

    def get(self):
        return self.client.request("GET", "/settings")

    def update(self, settings):
        return self.client.request("PUT", "/settings", json=settings)

    def get_theme(self):
        return self.client.request("GET", "/settings/theme")

    def update_theme(self, theme):
        return self.client.request("PUT", "/settings/theme", json={"theme": theme})

    def get_notification_settings(self):
        return self.client.request("GET", "/settings/notifications")

    def update_notification_settings(self, settings):
        return self.client.request("PUT", "/settings/notifications", json=settings)
