class Auth:
    def __init__(self, client):
        self.client = client

    def signup(self, email, password, name):
        return self.client.request("POST", "/auth/signup", json={
            "email": email,
            "password": password,
            "name": name
        })

    def login(self, email, password):
        return self.client.request("POST", "/auth/signin", json={
            "email": email,
            "password": password
        })

    def get_profile(self):
        return self.client.request("GET", "/auth/profile")
